Enum polkadot_overseer::ToOverseer [−][src]
pub enum ToOverseer {
SpawnJob {
name: &'static str,
subsystem: Option<&'static str>,
s: Pin<Box<dyn Future<Output = ()> + Send + 'static, Global>>,
},
SpawnBlockingJob {
name: &'static str,
subsystem: Option<&'static str>,
s: Pin<Box<dyn Future<Output = ()> + Send + 'static, Global>>,
},
}Expand description
A type of messages that are sent from Subsystem to [Overseer].
Used to launch jobs.
Variants
A message that wraps something the Subsystem is desiring to
spawn on the overseer and a oneshot::Sender to signal the result
of the spawn.
Fields of SpawnJob
Same as SpawnJob but for blocking tasks to be executed on a
dedicated thread pool.
Fields of SpawnBlockingJob